@@ -18,13 +18,13 @@ from cubicweb.entities import AnyEntity, fetch_config, adapters
 from cubes.vcsfile import queries
 from cubes.vcsfile.hooks import repo_cache_dir
 
-def rql_revision_content(repoeid, revnum, branch=None):
+def rql_revision_content(repoeid, revnum):
     """return rql query to get the repository content at a given revision"""
-    args = {'rev': revnum, 'x': repoeid, 'branch': branch}
+    args = {'rev': revnum, 'x': repoeid}
     return ('Any V,REV,F,D,N ORDERBY D,N WHERE '
             'V content_for F, F directory D, F name N, '
             'V from_revision VR, VR revision REV, '
-            'V at_revision AVR, AVR revision %(rev)s, AVR branch %(branch)s, '
+            'V at_revision AVR, AVR revision %(rev)s, '
             'AVR from_repository R, R eid %(x)s'
             ), args
 
@@ -51,7 +51,8 @@ class Repository(AnyEntity):
 
     @property
     def localcachepath(self):
-        """ return a path to the local repository cache
+        """return a path to the local repository cache (either `.local_cache`
+        or `.path`)
 
         Does make sense only for mercurial repositories.
         The path itself should be enforced unless some late
@@ -60,9 +61,10 @@ class Repository(AnyEntity):
         """
         if self.type != 'mercurial':
             raise TypeError('.localcachepath only makes sense on a mercurial repository')
-        if self.local_cache is None:
-            raise Exception('%s.local_cache does not exist yet' % self.eid)
-        return osp.join(repo_cache_dir(self._cw.vreg.config), self.local_cache)
+        path = self.local_cache or self.path
+        if path is None:
+            raise Exception('%s.local_cache or .path does not exist yet' % self.eid)
+        return osp.join(repo_cache_dir(self._cw.vreg.config), path)
 
     def dc_title(self):
         if self.title:
