@@ -143,7 +143,7 @@ def bw_nb_revisions(changelog):
 class HGRepository(repo.VCSRepository):
     type = 'hg'
 
-    def pull_or_clone_cache(self, url):
+    def pull_or_clone_cache(self, url, config):
         vui = vcsfile_ui(self)
         if not exists(self.path):
             pdir = dirname(self.path)
@@ -165,7 +165,8 @@ class HGRepository(repo.VCSRepository):
             # Wait 15s after a pull and re-pull the null revision, to make it
             # less likely we're missing in-flight obsolescence markers.
             # see #2818315
-            time.sleep(15)
+            if config.mode != 'test':
+                time.sleep(15)
             try:
                 hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url), rev=('null',))
             except (util.Abort, urllib2.URLError), ex:
@@ -174,8 +175,10 @@ class HGRepository(repo.VCSRepository):
     def import_content(self, repoentity, commitevery=1000):
         """import content from the mercurial repository"""
         assert self.eid == repoentity.eid
+        session = repoentity._cw
         if not exists(self.path):
-            self.pull_or_clone_cache(repoentity.source_url)
+            self.pull_or_clone_cache(repoentity.source_url,
+                                     session.vreg.config)
 
         with force_mercurial_utf8():
             try:
@@ -187,7 +190,6 @@ class HGRepository(repo.VCSRepository):
                 self.exception('Impossible to open repository %s (%s)', self, ex)
                 return
 
-            session = repoentity._cw
             knownheads = [(str(r.changeset), r.revision)
                           for r in repoentity.heads_rset().entities()]
 
